use anyhow::Error;
use redis::{aio::MultiplexedConnection, Client};
use sqlx::PgPool;
use std::net::SocketAddr;

use crate::cfg::Cfg;

#[derive(Clone)]
pub struct Ctx {
    pub cfg: Cfg,
    db: PgPool,
    cache: MultiplexedConnection,
}

impl Ctx {
    pub async fn new(cfg: Cfg) -> Result<Self, Error> {
        let db = PgPool::connect(&cfg.server.database_url).await?;
        let cache = Client::open(cfg.server.cache_url.as_str())?
            .get_multiplexed_async_connection()
            .await?;

        Ok(Self { cfg, db, cache })
    }

    pub fn bind_addr(&self) -> SocketAddr {
        SocketAddr::from(([127, 0, 0, 1], self.cfg.server.port))
    }

    pub fn db(&self) -> &PgPool {
        &self.db
    }

    pub fn cache(&self) -> MultiplexedConnection {
        self.cache.clone()
    }
}
