use std::net::IpAddr;

use chrono::{DateTime, Utc};
use ipnetwork::IpNetwork;
use serde::{Deserialize, Serialize};
use sqlx::{types::Json, FromRow};

use crate::cfg::BoardCfg;

#[derive(FromRow, Serialize, Deserialize, Clone)]
pub struct Account {
    pub username: String,
    pub password: String,
    pub owner: bool,
    pub permissions: Json<u64>,
    pub created: DateTime<Utc>,
}

#[derive(FromRow, Serialize, Deserialize)]
pub struct Board {
    pub id: String,
    pub name: String,
    pub description: String,
    pub config: Json<BoardCfg>,
    pub created: DateTime<Utc>,
}

#[derive(FromRow, Debug, Serialize, Deserialize, Clone)]
pub struct Ban {
    pub id: i32,
    pub ip_range: IpNetwork,
    pub reason: String,
    pub board: Option<String>,
    pub issued_by: String,
    pub appealable: bool,
    pub appeal: Option<String>,
    pub expires: Option<DateTime<Utc>>,
    pub created: DateTime<Utc>,
}

#[derive(Serialize, Deserialize, Clone)]
pub struct Report {
    pub reason: String,
    pub reporter_country: String,
    pub reporter_ip: IpAddr,
}

#[derive(FromRow, Serialize, Deserialize)]
pub struct Post {
    pub id: i64,
    pub board: String,
    pub thread: Option<i64>,
    pub name: String,
    pub user_id: String,
    pub tripcode: Option<String>,
    pub capcode: Option<String>,
    pub email: Option<String>,
    pub content: String,
    pub content_nomarkup: String,
    pub files: Json<Vec<File>>,
    pub password: String,
    pub country: String,
    pub ip: IpAddr,
    pub bumps: i32,
    pub replies: i32,
    pub sticky: bool,
    pub locked: bool,
    pub reported: Option<DateTime<Utc>>,
    pub reports: Json<Vec<Report>>,
    pub bumped: DateTime<Utc>,
    pub created: DateTime<Utc>,
}

#[derive(FromRow, Serialize, Deserialize)]
pub struct Banner {
    pub id: i32,
    pub banner: Json<File>,
}

#[derive(FromRow)]
pub struct NewsPost {
    pub id: i32,
    pub title: String,
    pub content: String,
    pub content_nomarkup: String,
    pub author: String,
    pub created: DateTime<Utc>,
}

#[derive(Serialize, Deserialize, Clone)]
pub struct File {
    pub original_name: String,
    pub format: String,
    pub thumb_format: Option<String>,
    pub spoiler: bool,
    pub width: u32,
    pub height: u32,
    pub timestamp: i64,
    pub size: usize,
}

pub struct LocalStats {
    pub post_count: i64,
    pub file_count: i64,
    pub file_size: i64,
}
