use sqlx::{query, query_as};

use super::models::NewsPost;
use crate::{ctx::Ctx, error::NekrochanError};

impl NewsPost {
    pub async fn create(
        ctx: &Ctx,
        title: String,
        content: String,
        content_nomarkup: String,
        author: String,
    ) -> Result<Self, NekrochanError> {
        let newspost = query_as("INSERT INTO news (title, content, content_nomarkup, author) VALUES ($1, $2, $3, $4) RETURNING *")
            .bind(title)
            .bind(content)
            .bind(content_nomarkup)
            .bind(author)
            .fetch_one(ctx.db())
            .await?;

        Ok(newspost)
    }

    pub async fn read(ctx: &Ctx, id: i32) -> Result<Option<Self>, NekrochanError> {
        let newspost = query_as("SELECT * FROM news WHERE id = $1")
            .bind(id)
            .fetch_optional(ctx.db())
            .await?;

        Ok(newspost)
    }

    pub async fn read_all(ctx: &Ctx) -> Result<Vec<Self>, NekrochanError> {
        let newsposts = query_as("SELECT * FROM news ORDER BY created DESC")
            .fetch_all(ctx.db())
            .await?;

        Ok(newsposts)
    }

    pub async fn read_latest(ctx: &Ctx) -> Result<Option<Self>, NekrochanError> {
        let newspost = query_as("SELECT * FROM news ORDER BY created DESC LIMIT 1")
            .fetch_optional(ctx.db())
            .await?;

        Ok(newspost)
    }

    pub async fn update(
        &self,
        ctx: &Ctx,
        content: String,
        content_nomarkup: String,
    ) -> Result<(), NekrochanError> {
        query("UPDATE news SET content = $1, content_nomarkup = $2 WHERE id = $3")
            .bind(content)
            .bind(content_nomarkup)
            .bind(self.id)
            .execute(ctx.db())
            .await?;

        Ok(())
    }

    pub async fn delete(&self, ctx: &Ctx) -> Result<(), NekrochanError> {
        query("DELETE FROM news WHERE id = $1")
            .bind(self.id)
            .execute(ctx.db())
            .await?;

        Ok(())
    }
}
