use enumflags2::{bitflags, BitFlags};

#[bitflags]
#[repr(u64)]
#[derive(Copy, Clone, Debug, PartialEq)]
pub enum Permissions {
    EditPosts,
    ManagePosts,
    Capcodes,
    CustomCapcodes,
    StaffLog,
    Reports,
    Bans,
    BoardBanners,
    BoardConfig,
    News,
    BypassBans,
    BypassBoardLock,
    BypassThreadLock,
    BypassCaptcha,
    BypassAntispam,
}

pub struct PermissionWrapper(BitFlags<Permissions>, bool);

impl PermissionWrapper {
    pub fn new(perms: u64, owner: bool) -> Self {
        Self(BitFlags::from_bits_truncate(perms), owner)
    }
}

impl PermissionWrapper {
    pub fn integer(&self) -> u64 {
        self.0.bits()
    }

    pub fn owner(&self) -> bool {
        self.1
    }

    pub fn edit_posts(&self) -> bool {
        self.0.contains(Permissions::EditPosts)
    }

    pub fn manage_posts(&self) -> bool {
        self.0.contains(Permissions::ManagePosts)
    }

    pub fn capcodes(&self) -> bool {
        self.0.contains(Permissions::Capcodes)
    }

    pub fn custom_capcodes(&self) -> bool {
        self.0.contains(Permissions::CustomCapcodes)
    }

    pub fn staff_log(&self) -> bool {
        self.0.contains(Permissions::StaffLog)
    }

    pub fn reports(&self) -> bool {
        self.0.contains(Permissions::Reports)
    }

    pub fn bans(&self) -> bool {
        self.0.contains(Permissions::Bans)
    }

    pub fn banners(&self) -> bool {
        self.0.contains(Permissions::BoardBanners)
    }

    pub fn board_config(&self) -> bool {
        self.0.contains(Permissions::BoardConfig)
    }

    pub fn news(&self) -> bool {
        self.0.contains(Permissions::News)
    }

    pub fn bypass_bans(&self) -> bool {
        self.0.contains(Permissions::BypassBans)
    }

    pub fn bypass_board_lock(&self) -> bool {
        self.0.contains(Permissions::BypassBoardLock)
    }

    pub fn bypass_thread_lock(&self) -> bool {
        self.0.contains(Permissions::BypassThreadLock)
    }

    pub fn bypass_captcha(&self) -> bool {
        self.0.contains(Permissions::BypassCaptcha)
    }

    pub fn bypass_antispam(&self) -> bool {
        self.0.contains(Permissions::BypassAntispam)
    }
}
