use encoding::{all::WINDOWS_31J, EncoderTrap, Encoding};
use pwhash::{
    bcrypt::{self, BcryptSetup},
    unix::crypt,
};

pub fn tripcode(password: &str) -> String {
    let password = WINDOWS_31J.encode(password, EncoderTrap::Replace).unwrap();

    let salt = [password.as_ref(), "H.".as_bytes()].concat();
    let salt = &salt[1..3];
    let salt = salt
        .iter()
        .map(|c| match c {
            46..=122 => *c,
            _ => 46,
        } as char)
        .map(|c| match c {
            ':' => 'A',
            ';' => 'B',
            '<' => 'C',
            '=' => 'D',
            '>' => 'E',
            '?' => 'F',
            '@' => 'G',
            '[' => 'a',
            '\\' => 'b',
            ']' => 'c',
            '^' => 'd',
            '_' => 'e',
            '`' => 'f',
            _ => c,
        })
        .collect::<String>();

    let trip = crypt(password, &salt).unwrap();

    trip[3..].to_owned()
}

pub fn secure_tripcode(password: &str, tripcode_secret: &str) -> String {
    let trip = bcrypt::hash_with(
        BcryptSetup {
            salt: Some(tripcode_secret),
            ..Default::default()
        },
        password,
    )
    .unwrap();

    let trip = &trip[trip.len() - 10..];

    trip.into()
}
