use actix_web::{post, web::Data, HttpRequest, HttpResponse};
use askama::Template;
use serde::Deserialize;

use crate::{
    ctx::Ctx,
    db::models::Post,
    error::NekrochanError,
    qsform::QsForm,
    web::{actions::get_posts_from_ids, template_response, TemplateCtx},
};

#[derive(Deserialize)]
pub struct EditPostsForm {
    #[serde(default)]
    pub posts: Vec<String>,
}

#[derive(Template)]
#[template(path = "edit-posts.html")]
struct EditPostsTemplate {
    tcx: TemplateCtx,
    posts: Vec<Post>,
}

#[post("/edit-posts")]
pub async fn edit_posts(
    ctx: Data<Ctx>,
    req: HttpRequest,
    QsForm(form): QsForm<EditPostsForm>,
) -> Result<HttpResponse, NekrochanError> {
    let tcx = TemplateCtx::new(&ctx, &req).await?;

    if !(tcx.perms.owner() || tcx.perms.edit_posts()) {
        return Err(NekrochanError::InsufficientPermissionError);
    }

    let posts = get_posts_from_ids(&ctx, form.posts).await;
    let template = EditPostsTemplate { tcx, posts };

    template_response(&template)
}
