use actix_web::{get, web::Data, HttpRequest, HttpResponse};
use askama::Template;

use crate::{
    ctx::Ctx,
    db::models::Account,
    error::NekrochanError,
    web::{
        tcx::{account_from_auth, TemplateCtx},
        template_response,
    },
};

#[derive(Template)]
#[template(path = "staff/account.html")]
struct AccountTemplate {
    tcx: TemplateCtx,
    account: Account,
}

#[get("/staff/account")]
pub async fn account(ctx: Data<Ctx>, req: HttpRequest) -> Result<HttpResponse, NekrochanError> {
    let tcx = TemplateCtx::new(&ctx, &req).await?;
    let account = account_from_auth(&ctx, &req).await?;
    let template = AccountTemplate { tcx, account };

    template_response(&template)
}
