use actix_web::{get, web::Data, HttpRequest, HttpResponse};
use askama::Template;

use crate::{
    ctx::Ctx,
    db::models::Account,
    error::NekrochanError,
    filters,
    web::{tcx::TemplateCtx, template_response},
};

#[derive(Template)]
#[template(path = "staff/accounts.html")]
struct AccountsTemplate {
    tcx: TemplateCtx,
    accounts: Vec<Account>,
}

#[get("/staff/accounts")]
pub async fn accounts(ctx: Data<Ctx>, req: HttpRequest) -> Result<HttpResponse, NekrochanError> {
    let tcx = TemplateCtx::new(&ctx, &req).await?;
    let accounts = Account::read_all(&ctx).await?;
    let template = AccountsTemplate { tcx, accounts };

    template_response(&template)
}
