use actix_multipart::form::{tempfile::TempFile, MultipartForm};
use actix_web::{post, web::Data, HttpRequest, HttpResponse};

use crate::{
    ctx::Ctx,
    db::models::{Banner, File},
    error::NekrochanError,
    web::tcx::account_from_auth,
};

#[derive(MultipartForm)]
pub struct AddBannersForm {
    #[multipart(rename = "files[]")]
    files: Vec<TempFile>,
}

#[post("/staff/actions/add-banners")]
pub async fn add_banners(
    ctx: Data<Ctx>,
    req: HttpRequest,
    MultipartForm(form): MultipartForm<AddBannersForm>,
) -> Result<HttpResponse, NekrochanError> {
    let account = account_from_auth(&ctx, &req).await?;

    if !(account.perms().owner() || account.perms().banners()) {
        return Err(NekrochanError::InsufficientPermissionError);
    }

    let mut cfg = ctx.cfg.clone();

    cfg.files.videos = false;

    for file in form.files {
        Banner::create(&ctx, File::new(&cfg, file, false, false).await?).await?;
    }

    let res = HttpResponse::SeeOther()
        .append_header(("Location", "/staff/banners"))
        .finish();

    Ok(res)
}
