use actix_web::{post, web::Data, HttpRequest, HttpResponse};
use pwhash::bcrypt::{hash, verify};
use serde::Deserialize;

use crate::{ctx::Ctx, error::NekrochanError, qsform::QsForm, web::tcx::account_from_auth};

#[derive(Deserialize)]
pub struct ChangePasswordForm {
    old_password: String,
    new_password: String,
}

#[post("/staff/actions/change-password")]
pub async fn change_password(
    ctx: Data<Ctx>,
    req: HttpRequest,
    QsForm(form): QsForm<ChangePasswordForm>,
) -> Result<HttpResponse, NekrochanError> {
    let account = account_from_auth(&ctx, &req).await?;

    if !verify(form.old_password, &account.password) {
        return Err(NekrochanError::IncorrectCredentialError);
    }

    if form.new_password.len() < 8 {
        return Err(NekrochanError::PasswordFormatError);
    }

    let password = hash(form.new_password)?;

    account.update_password(&ctx, password).await?;

    let res = HttpResponse::SeeOther()
        .append_header(("Location", "/staff/account"))
        .finish();

    Ok(res)
}
