use actix_web::{post, web::Data, HttpRequest, HttpResponse};
use std::{collections::HashMap, fmt::Write};

use crate::{
    ctx::Ctx,
    db::models::NewsPost,
    error::NekrochanError,
    markup::markup,
    qsform::QsForm,
    web::{actions::ActionTemplate, tcx::TemplateCtx, template_response},
};

#[post("/staff/actions/edit-news")]
pub async fn edit_news(
    ctx: Data<Ctx>,
    req: HttpRequest,
    QsForm(edits): QsForm<HashMap<i32, String>>,
) -> Result<HttpResponse, NekrochanError> {
    let tcx = TemplateCtx::new(&ctx, &req).await?;

    if !(tcx.perms.owner() || tcx.perms.news()) {
        return Err(NekrochanError::InsufficientPermissionError);
    }

    let mut news = Vec::new();

    for id in edits.keys() {
        if let Some(newspost) = NewsPost::read(&ctx, *id).await? {
            news.push(newspost);
        }
    }

    let news = news
        .into_iter()
        .map(|newspost| (newspost.id, newspost))
        .collect::<HashMap<i32, NewsPost>>();

    let mut response = String::new();
    let mut news_edited = 0;

    for (id, content_nomarkup) in edits {
        let newspost = &news[&id];

        if !tcx.perms.owner() && tcx.account != Some(newspost.author.clone()) {
            writeln!(
                &mut response,
                "[Chyba] pouze vlastník nebo autor může upravit novinky."
            )
            .ok();

            continue;
        }

        let content_nomarkup = content_nomarkup.trim();
        let content = markup(&ctx, None, None, content_nomarkup).await?;

        newspost
            .update(&ctx, content, content_nomarkup.into())
            .await?;
        news_edited += 1;
    }

    if news_edited != 0 {
        writeln!(&mut response, "[Úspěch] Upraveny novinky: {news_edited}").ok();
    }

    let template = ActionTemplate { tcx, response };

    template_response(&template)
}
