use std::fmt::Write;

use actix_web::{post, web::Data, HttpRequest, HttpResponse};
use serde::Deserialize;

use crate::{
    ctx::Ctx,
    db::models::NewsPost,
    error::NekrochanError,
    qsform::QsForm,
    web::{actions::ActionTemplate, template_response, TemplateCtx},
};

#[derive(Deserialize)]
pub struct RemoveNewsForm {
    #[serde(default)]
    pub news: Vec<i32>,
}

#[post("/staff/actions/remove-news")]
pub async fn remove_news(
    ctx: Data<Ctx>,
    req: HttpRequest,
    QsForm(form): QsForm<RemoveNewsForm>,
) -> Result<HttpResponse, NekrochanError> {
    let tcx = TemplateCtx::new(&ctx, &req).await?;

    if !(tcx.perms.owner() || tcx.perms.news()) {
        return Err(NekrochanError::InsufficientPermissionError);
    }

    let mut news = Vec::new();

    for id in form.news {
        if let Some(newspost) = NewsPost::read(&ctx, id).await? {
            news.push(newspost);
        }
    }

    let mut response = String::new();
    let mut news_removed = 0;

    for newspost in news {
        if !tcx.perms.owner() && tcx.account != Some(newspost.author.clone()) {
            writeln!(
                &mut response,
                "[Chyba] pouze vlastník nebo autor může odstranit novinky."
            )
            .ok();

            continue;
        }

        newspost.delete(&ctx).await?;
        news_removed += 1;
    }

    if news_removed != 0 {
        writeln!(&mut response, "[Úspěch] Odstraněny novinky: {news_removed}").ok();
    }

    let template = ActionTemplate { tcx, response };

    template_response(&template)
}
