use actix_web::{post, web::Data, HttpRequest, HttpResponse};
use serde::Deserialize;

use crate::{
    ctx::Ctx, db::models::Account, error::NekrochanError, qsform::QsForm,
    web::tcx::account_from_auth,
};

#[derive(Deserialize)]
pub struct TransferOwnershipForm {
    account: String,
}

#[post("/staff/actions/transfer-ownership")]
pub async fn transfer_ownership(
    ctx: Data<Ctx>,
    req: HttpRequest,
    QsForm(form): QsForm<TransferOwnershipForm>,
) -> Result<HttpResponse, NekrochanError> {
    let old_owner = account_from_auth(&ctx, &req).await?;

    if !old_owner.perms().owner() {
        return Err(NekrochanError::InsufficientPermissionError);
    }

    let new_owner = form.account;
    let new_owner = Account::read(&ctx, new_owner.clone())
        .await?
        .ok_or(NekrochanError::AccountNotFound(new_owner))?;

    old_owner.update_owner(&ctx, false).await?;
    new_owner.update_owner(&ctx, true).await?;

    let res = HttpResponse::SeeOther()
        .append_header(("Location", "/staff/account"))
        .finish();

    Ok(res)
}
