use actix_web::{get, web::Data, HttpRequest, HttpResponse};
use askama::Template;

use crate::{
    ctx::Ctx,
    db::models::Banner,
    error::NekrochanError,
    web::{
        tcx::{account_from_auth, TemplateCtx},
        template_response,
    },
};

#[derive(Template)]
#[template(path = "staff/banners.html")]
struct BannersTemplate {
    tcx: TemplateCtx,
    banners: Vec<Banner>,
}

#[get("/staff/banners")]
pub async fn banners(ctx: Data<Ctx>, req: HttpRequest) -> Result<HttpResponse, NekrochanError> {
    let tcx = TemplateCtx::new(&ctx, &req).await?;
    let account = account_from_auth(&ctx, &req).await?;

    if !(account.perms().owner() || account.perms().banners()) {
        return Err(NekrochanError::InsufficientPermissionError);
    }

    let banners = Banner::read_all(&ctx).await?;
    let template = BannersTemplate { tcx, banners };

    template_response(&template)
}
