use actix_web::{get, web::Data, HttpRequest, HttpResponse};
use askama::Template;

use crate::{
    ctx::Ctx,
    db::models::Ban,
    error::NekrochanError,
    filters,
    web::{
        tcx::{account_from_auth, TemplateCtx},
        template_response,
    },
};

#[derive(Template)]
#[template(path = "staff/bans.html")]
struct BansTemplate {
    tcx: TemplateCtx,
    bans: Vec<Ban>,
}

#[get("/staff/bans")]
pub async fn bans(ctx: Data<Ctx>, req: HttpRequest) -> Result<HttpResponse, NekrochanError> {
    let tcx = TemplateCtx::new(&ctx, &req).await?;
    let account = account_from_auth(&ctx, &req).await?;

    if !(account.perms().owner() || account.perms().bans()) {
        return Err(NekrochanError::InsufficientPermissionError);
    }

    let bans = Ban::read_all(&ctx).await?;
    let template = BansTemplate { tcx, bans };

    template_response(&template)
}
