use actix_web::{
    get,
    web::{Data, Path},
    HttpRequest, HttpResponse,
};
use askama::Template;

use crate::{
    ctx::Ctx,
    db::models::Board,
    error::NekrochanError,
    web::{
        tcx::{account_from_auth, TemplateCtx},
        template_response,
    },
};

#[derive(Template)]
#[template(path = "staff/board-config.html")]
struct BannersTemplate {
    tcx: TemplateCtx,
    board: Board,
}

#[get("/staff/board-config/{board}")]
pub async fn board_config(
    ctx: Data<Ctx>,
    req: HttpRequest,
    board: Path<String>,
) -> Result<HttpResponse, NekrochanError> {
    let tcx = TemplateCtx::new(&ctx, &req).await?;
    let account = account_from_auth(&ctx, &req).await?;

    if !(account.perms().owner() || account.perms().board_config()) {
        return Err(NekrochanError::InsufficientPermissionError);
    }

    let board = board.into_inner();
    let board = Board::read(&ctx, board.clone())
        .await?
        .ok_or(NekrochanError::BoardNotFound(board))?;

    let template = BannersTemplate { tcx, board };

    template_response(&template)
}
