use actix_web::{get, web::Data, HttpRequest, HttpResponse};
use askama::Template;

use crate::{
    ctx::Ctx,
    db::models::Board,
    error::NekrochanError,
    filters,
    web::{
        tcx::{account_from_auth, TemplateCtx},
        template_response,
    },
};

#[derive(Template)]
#[template(path = "staff/boards.html")]
struct BoardsTemplate {
    tcx: TemplateCtx,
    boards: Vec<Board>,
}

#[get("/staff/boards")]
pub async fn boards(ctx: Data<Ctx>, req: HttpRequest) -> Result<HttpResponse, NekrochanError> {
    let tcx = TemplateCtx::new(&ctx, &req).await?;
    let account = account_from_auth(&ctx, &req).await?;

    if !(account.perms().owner() || account.perms().board_config() || account.perms().banners()) {
        return Err(NekrochanError::InsufficientPermissionError);
    }

    let boards = Board::read_all(&ctx).await?;
    let template = BoardsTemplate { tcx, boards };

    template_response(&template)
}
