use actix_web::{post, web::Data, HttpRequest, HttpResponse};
use askama::Template;
use serde::Deserialize;

use crate::{
    ctx::Ctx,
    db::models::NewsPost,
    error::NekrochanError,
    filters,
    qsform::QsForm,
    web::{template_response, TemplateCtx},
};

#[derive(Deserialize)]
pub struct EditNewsForm {
    pub news: Vec<i32>,
}

#[derive(Template)]
#[template(path = "staff/edit-news.html")]
struct EditNewsTemplate {
    tcx: TemplateCtx,
    news: Vec<NewsPost>,
}

#[post("/staff/edit-news")]
pub async fn edit_news(
    ctx: Data<Ctx>,
    req: HttpRequest,
    QsForm(form): QsForm<EditNewsForm>,
) -> Result<HttpResponse, NekrochanError> {
    let tcx = TemplateCtx::new(&ctx, &req).await?;

    if !(tcx.perms.owner() || tcx.perms.news()) {
        return Err(NekrochanError::InsufficientPermissionError);
    }

    let mut news = Vec::new();

    for id in form.news {
        if let Some(newspost) = NewsPost::read(&ctx, id).await? {
            news.push(newspost);
        }
    }

    let template = EditNewsTemplate { tcx, news };

    template_response(&template)
}
