use actix_web::{get, web::Data, HttpRequest, HttpResponse};
use askama::Template;

use crate::{
    ctx::Ctx,
    db::models::NewsPost,
    error::NekrochanError,
    web::{tcx::TemplateCtx, template_response},
};

#[derive(Template)]
#[template(path = "staff/news.html")]
struct NewsTemplate {
    tcx: TemplateCtx,
    news: Vec<NewsPost>,
}

#[get("/staff/news")]
pub async fn news(ctx: Data<Ctx>, req: HttpRequest) -> Result<HttpResponse, NekrochanError> {
    let tcx = TemplateCtx::new(&ctx, &req).await?;
    let news = NewsPost::read_all(&ctx).await?;
    let template = NewsTemplate { tcx, news };

    template_response(&template)
}
