use actix_web::{
    get,
    web::{Data, Path},
    HttpRequest, HttpResponse,
};
use askama::Template;

use crate::{
    ctx::Ctx,
    db::models::Account,
    error::NekrochanError,
    web::{
        tcx::{account_from_auth, TemplateCtx},
        template_response,
    },
};

#[derive(Template)]
#[template(path = "staff/permissions.html")]
struct PermissionsTemplate {
    tcx: TemplateCtx,
    account: Account,
}

#[get("/staff/permissions/{account}")]
pub async fn permissions(
    ctx: Data<Ctx>,
    req: HttpRequest,
    path: Path<String>,
) -> Result<HttpResponse, NekrochanError> {
    let tcx = TemplateCtx::new(&ctx, &req).await?;
    let _ = account_from_auth(&ctx, &req).await?;

    let account = path.into_inner();
    let account = Account::read(&ctx, account.clone())
        .await?
        .ok_or(NekrochanError::AccountNotFound(account))?;

    let template = PermissionsTemplate { tcx, account };

    template_response(&template)
}
