use actix_web::{
    get,
    http::StatusCode,
    web::{Data, Path},
    HttpRequest, HttpResponse,
};
use askama::Template;

use crate::{
    ctx::Ctx,
    db::models::{Board, Post},
    error::NekrochanError,
    filters,
    web::{tcx::TemplateCtx, template_response},
};

#[derive(Template)]
#[template(path = "thread.html")]
struct ThreadTemplate {
    tcx: TemplateCtx,
    board: Board,
    thread: Post,
    replies: Vec<Post>,
}

#[get("/boards/{board}/{thread}")]
pub async fn thread(
    ctx: Data<Ctx>,
    req: HttpRequest,
    path: Path<(String, i64)>,
) -> Result<HttpResponse, NekrochanError> {
    let tcx = TemplateCtx::new(&ctx, &req).await?;

    let (board, id) = path.into_inner();
    let board = Board::read(&ctx, board.clone())
        .await?
        .ok_or(NekrochanError::BoardNotFound(board))?;

    let thread = Post::read(&ctx, board.id.clone(), id)
        .await?
        .ok_or(NekrochanError::PostNotFound(board.id.clone(), id))?;

    if thread.thread.is_some() {
        return Ok(HttpResponse::build(StatusCode::PERMANENT_REDIRECT)
            .append_header(("Location", thread.post_url()))
            .finish());
    }

    let replies = thread.read_replies(&ctx).await?;

    let template = ThreadTemplate {
        tcx,
        board,
        thread,
        replies,
    };

    template_response(&template)
}
